commit-gnue
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

gnue/gnue-common setup.py src/GConnections.py


From: James Thompson
Subject: gnue/gnue-common setup.py src/GConnections.py
Date: Sun, 04 Nov 2001 17:13:34 -0500

CVSROOT:        /cvs
Module name:    gnue
Changes by:     James Thompson <address@hidden> 01/11/04 17:13:33

Modified files:
        gnue-common    : setup.py 
        gnue-common/src: GConnections.py 

Log message:
        Some changes to make gnuef work on win32

CVSWeb URLs:
http://savannah.gnu.org/cgi-bin/viewcvs/gnue/gnue-common/setup.py.diff?cvsroot=OldCVS&tr1=1.24&tr2=1.25&r1=text&r2=text
http://savannah.gnu.org/cgi-bin/viewcvs/gnue/gnue-common/src/GConnections.py.diff?cvsroot=OldCVS&tr1=1.20&tr2=1.21&r1=text&r2=text

Patches:
Index: gnue/gnue-common/src/GConnections.py
diff -u gnue/gnue-common/src/GConnections.py:1.20 
gnue/gnue-common/src/GConnections.py:1.21
--- gnue/gnue-common/src/GConnections.py:1.20   Sun Nov  4 13:36:32 2001
+++ gnue/gnue-common/src/GConnections.py        Sun Nov  4 17:13:33 2001
@@ -215,10 +215,6 @@
 # Load the correct DBdriver from gnue/common/dbdrivers/*/
 #
 def _load_dbdriver(driver, type, connectionManager):
-
-  if sys.platform == 'win32':
-    os.putenv('PYTHONCASEOK','1')
-
   try:
     dbdriver = __import__("gnue/common/dbdrivers/%s/DBdriver" % (driver))
   except ImportError, err:



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
Index: gnue/gnue-common/setup.py
diff -u gnue/gnue-common/setup.py:1.24 gnue/gnue-common/setup.py:1.25
--- gnue/gnue-common/setup.py:1.24      Fri Nov  2 18:14:08 2001
+++ gnue/gnue-common/setup.py   Sun Nov  4 17:13:33 2001
@@ -116,7 +116,7 @@
     for key in dict.keys():
       options.append('%s = "%s"' % (key, 
string.replace(dict[key][1],'"','\\"')))
 
-    GNUe_py = """
+    gnue_sys_py = """
 #
 # Copyright 2001 Free Software Foundation
 #
@@ -149,8 +149,8 @@
   sys.path.insert(0,install_lib)
 """ % string.join(options,'\n')
 
-    output = open("GNUe.py", "w")
-    output.write(GNUe_py)
+    output = open("gnue_sys.py", "w")
+    output.write(gnue_sys_py)
     output.close()
 
 
@@ -201,7 +201,7 @@
   if sys.platform != 'win32':
     os.remove ("setup.cfg")
 
   # This is a nasty hack to get GNUe.py (and only GNUe.py)
   # to install to site_packages
   file = open ("setup.cfg","w")
   file.write ("[build]\n"
@@ -212,14 +212,14 @@
 
 
 distutils.core.setup (name = "GNUe-Common",
-       version = "0.0.3",
+       version = "0.1.0",
        description = "Base files of a GNU Enterprise Tools install",
        long_description = "",
        author = "GNUe Project",
        author_email = "address@hidden",
        url = "http://www.gnue.org";,
        # Override certain command classes with our own ones
-       py_modules = ['GNUe'],
+       py_modules = ['gnue_sys'],
        scripts = [],
        data_files = None,
        packages = []
@@ -201,7 +201,7 @@
     os.remove ("setup.cfg")
 
-  # This is a nasty hack to get GNUe.py (and only GNUe.py)
+  # This is a nasty hack to get gnue_sys (and only gnue_sys.py)
   # to install to site_packages
   file = open ("setup.cfg","w")